@@ -1,4 +1,6 @@
 pub mod misc;
 pub mod text;
+pub mod path;
+pub mod color;
 
 pub struct BevyUtil();
